@@ -2,7 +2,7 @@
 
 
 from django_filters import Filter, FilterSet
-from django_property_filter.filters import EXPLICIST_ONLY_FILTERS
+from django_property_filter.filters import EXPLICIT_ONLY_FILTERS
 
 
 class PropertyFilterSet(FilterSet):
@@ -10,17 +10,14 @@ class PropertyFilterSet(FilterSet):
 
     def __init__(self, *args, **kwargs):
         """Construct a PropertyFilterSet."""
-        super().__init__(*args, **kwargs)
         self._setup_property_filters()
+        super().__init__(*args, **kwargs)
 
-    def _add_filter(self, filter_class, property_fld_name, lookup_expr):
+    def _add_filter(self, filter_class, field_name, lookup_expr):
         """Add a Filter."""
-        filter_name = F'{property_fld_name}__{lookup_expr}'
-        self.filters[filter_name] = filter_class(property_fld_name=property_fld_name, lookup_expr=lookup_expr)
-
-        # propagate the model and filterset to the filters
-        self.filters[filter_name].model = self.queryset.model
-        self.filters[filter_name].parent = self
+        filter_name = F'{field_name}__{lookup_expr}'
+        self.base_filters[filter_name] = filter_class(  # pylint: disable=no-member
+            field_name=field_name, lookup_expr=lookup_expr)
 
     def _setup_property_filters(self):
         """Set up implicit filters."""
@@ -36,7 +33,7 @@ class PropertyFilterSet(FilterSet):
                 if not issubclass(prop_filter_class, Filter):
                     raise ValueError(F'{prop_filter_class} is not a subclass of {Filter}')
 
-                if prop_filter_class in EXPLICIST_ONLY_FILTERS:
+                if prop_filter_class in EXPLICIT_ONLY_FILTERS:
                     raise ValueError(F'{prop_filter_class} can only be declared Explicitely')
 
                 if not isinstance(prop_fld_name, str):
