@@ -1,5 +1,34 @@
 """Utility functionality."""
 
+from django.db.models import Case, When
+
+
+def sort_queryset(sort_property, queryset):
+    """Sort the queryset by the given property name. "-" for descending is supported."""
+    # Identify the sort order
+    descending = False
+    if sort_property.startswith('-'):
+        descending = True
+        sort_property = sort_property[1:]
+
+    # Build a list of pk and value, this might become very large depending on data type
+    value_list = []
+    for obj in queryset:
+        property_value = get_value_for_db_field(obj, sort_property)
+        value_list.append((obj.pk, property_value))
+
+    # Sort the list of tuples
+    value_list = sorted(value_list, key=lambda x: x[1], reverse=descending)
+
+    # Get a list of sorted primary keys
+    value_list = [entry[0] for entry in value_list]
+
+    # Sort the Queryset
+    preserved = Case(*[When(pk=pk, then=pos) for pos, pk in enumerate(value_list)])
+    queryset = queryset.filter(pk__in=value_list).order_by(preserved)
+
+    return queryset
+
 
 def get_value_for_db_field(obj, field_str):
     """Lookup a model field or property."""
@@ -15,8 +44,6 @@ def get_value_for_db_field(obj, field_str):
 
 def compare_by_lookup_expression(lookup_expr, lookup_value, property_value):  # pylint: disable=too-many-branches
     """Compare Lookup Expressions."""
-    # Handle Special case if only 1 case of range given
-
     result = False
 
     # Do the Comparison
